@@ -319,6 +319,15 @@ Java_org_linkgrammar_LinkGrammar_getVersion(JNIEnv *env, jclass cls)
 	return j;
 }
 
+JNIEXPORT jstring JNICALL
+Java_org_linkgrammar_LinkGrammar_getDictVersion(JNIEnv *env, jclass cls)
+{
+	per_thread_data *ptd = get_ptd(env, cls);;
+	const char *s = linkgrammar_get_dict_version(ptd->dict);
+	jstring j = (*env)->NewStringUTF(env, s);
+	return j;
+}
+
 JNIEXPORT void JNICALL
 Java_org_linkgrammar_LinkGrammar_setMaxParseSeconds(JNIEnv *env, jclass cls, jint maxParseSeconds)
 {
@@ -711,6 +720,9 @@ Java_org_linkgrammar_LinkGrammar_getLinkString(JNIEnv *env, jclass cls)
  * Class:		 LinkParser
  * Method:		isPastTenseForm
  * Signature: (Ljava/lang/String;)Z
+ *
+ * @deprecated -- past-tense verbs are tagged with .v-d or .w-d or .q-d
+ * subscripts. use those instead to figure out if a verb is past tense.
  */
 JNIEXPORT jboolean JNICALL
 Java_org_linkgrammar_LinkGrammar_isPastTenseForm(JNIEnv *env, jclass cls, jstring str)
