@@ -23,17 +23,20 @@ LINK_BEGIN_DECLS
 *
 ***********************************************************************/
 
+typedef struct Dictionary_s * Dictionary;
+
 link_public_api(const char *)
 	linkgrammar_get_version(void);
 
+link_public_api(const char *)
+	linkgrammar_get_dict_version(Dictionary);
+
 /**********************************************************************
 *
 * Functions to manipulate Dictionaries
 *
 ***********************************************************************/
 
-typedef struct Dictionary_s * Dictionary;
-
 link_public_api(Dictionary)
      dictionary_create(const char * dict_name,
                        const char * pp_name,
@@ -127,6 +130,10 @@ link_public_api(void)
      parse_options_set_cost_model_type(Parse_Options opts, int cm);
 link_public_api(int)
      parse_options_get_cost_model_type(Parse_Options opts);
+link_public_api(void)
+     parse_options_set_use_sat_parser(Parse_Options opts, int use_sat_solver);
+link_public_api(int)
+     parse_options_get_use_sat_parser(Parse_Options opts);
 link_public_api(int)
      parse_options_timer_expired(Parse_Options opts);
 link_public_api(int)
@@ -224,6 +231,8 @@ link_public_api(Sentence)
      sentence_create(const char *input_string, Dictionary dict);
 link_public_api(void)
      sentence_delete(Sentence sent);
+link_public_api(int)
+     sentence_split(Sentence sent, Parse_Options opts);
 link_public_api(int)
      sentence_parse(Sentence sent, Parse_Options opts);
 link_public_api(int)
