@@ -86,8 +86,8 @@
    this number multiplied times the number of costly connectors on any
    disjunct must fit into an integer. */
 
-#define NOCUTOFF 1000
-/* no connector will have cost this high */
+/* Upper bound on the cost of any connector. */
+#define MAX_CONNECTOR_COST 1000.0f
 
 #define LEFT_WALL_DISPLAY  ("LEFT-WALL")   /* the string to use to show the wall */
 #define LEFT_WALL_SUPPRESS ("Wd") /* If this connector is used on the wall, */
@@ -233,17 +233,15 @@ struct Word_struct
  * (AND, OR or TERMINAL).  If it is not a terminal it has a list
  * (an E_list) of children.
  */
-typedef struct E_list_struct E_list;
-
 struct Exp_struct
 {
-    Exp * next;
-    char type;            /* one of three types, see above */
+    Exp * next; /* Used only for mem management,for freeing */
+    char type;  /* One of three types, see above */
     char dir;   /* '-' means to the left, '+' means to right (for connector) */
     char multi; /* TRUE if a multi-connector (for connector)  */
     union {
-        E_list * l;       /* only needed for non-terminals */
-        const char * string;    /* only needed if it's a connector */
+        E_list * l;           /* only needed for non-terminals */
+        const char * string;  /* only needed if it's a connector */
     } u;
     float cost;   /* The cost of using this expression.
                      Only used for non-terminals */
@@ -331,7 +329,8 @@ struct Linkage_info_struct
     char improper_fat_linkage;
     char inconsistent_domains;
     short N_violations;
-    short null_cost, unused_word_cost, disjunct_cost, and_cost, link_cost;
+    short null_cost, unused_word_cost, and_cost, link_cost;
+    float disjunct_cost;
     double corpus_cost;
     Andlist * andlist;
     int island[MAX_SENTENCE];
