@@ -49,6 +49,9 @@
 /* The Microsoft Visual C compiler doesn't support the "inline" keyword. */
 #define inline
 
+/* MS Visual C does not have any function normally found in strings.h */
+/* In particular, be careful to avoid including strings.h */
+
 /* MS Visual C uses non-standard string function names */
 #define snprintf _snprintf
 #define vsnprintf _vsnprintf
@@ -56,12 +59,18 @@
 #define strdup _strdup
 #define strncasecmp(a,b,s) strnicmp((a),(b),(s))
 
+/* MS Visual C does not support some C99 standard floating-point functions */
+#define fmaxf(a,b) ((a) > (b) ? (a) : (b))
+
 #endif /* _MSC_VER */
 
-/* Appearntly, MinGW is also missing a variety of standard fuctions */
-/* MINGW is also known as MSYS */
+/* Appearently, MinGW is also missing a variety of standard fuctions.
+ * Not surprising, since MinGW is intended for compiling Windows
+ * programs on Windows.
+ * MINGW is also known as MSYS */
 #if defined(_MSC_VER) || defined(__MINGW32__)
-/* No langinfo Windows */
+
+/* No langinfo in Windows or MinGW */
 #define nl_langinfo(X) ""
 
 /* strtok_r is missing in Windows */
